#ifndef AKENTI_REQUESTS_HPP
#define AKENTI_REQUESTS_HPP

#include "AkentiRequest.hpp" 
#include "Xerces-Decls.hpp"
#include <vector>
#include <string>

using std::vector;
using std::string;

namespace Akenti {

/**
  * Holds an ordered list of <i>AkentiRequest<i>.
  *
  * @see AkentiRequest.
  */
class AkentiRequests {

public:

  /**
    * Constructor.
    */
  AkentiRequests();

  /**
    * Returns the number of <i>AkentiRequest</i>s in this <i>AkentiRequests<i>.
    */
  int numOfRequests() const;

  /**
    * Appends an <i>AkentiRequest</i>s to this <i>AkentiRequests<i>.
    */
  void addRequest(const AkentiRequest& req);

  /**
    * Returns the <i>AkentiRequest</i> at index <i>idx</i>.
    */
  const AkentiRequest& getRequestAt(int index) const;

  /**
    * Creates a DOMElement from this <i>AkentiRequests</i>.
    */
  DOMElement* toXML() const;

  /**
    * Initializes this <i>AkentiRequests<i> from a DOMElement.
    */
  void fromXML(const DOMElement* requests);

  /**
    * Used for debugging.
    */
  string toString() const;

private:

  vector<AkentiRequest> requests;

};

}

#endif

