#ifndef AKENTI_RESPONSE_HPP
#define AKENTI_RESPONSE_HPP

#include <string>
#include "ref_ptr.hpp"
#include "Xerces-Decls.hpp"
#include "AkentiMessage.hpp"

using std::string;

namespace Akenti {

/**
  * Base class to handle Akenti responses.
  *
  * @see AkentiMessage
  */
class AkentiResponse {

public:

  /**
    * Constructor.
    */
  AkentiResponse();

  /**
    * Destructor.
    */
  ~AkentiResponse();

  /**
   * Set the message id.
    */
  void setID(int id);

  /**
   * Return the message id
    */
  int getID() const;

  /**
    * Sets the status message
    */
  void setAkentiMessage(const AkentiMessage& mesg);

  /**
    * Returns the status mesage.
    */
  const AkentiMessage& getAkentiMessage() const;

  /**
    * Returns a an XML string representation.
    */
  string toString() const;

  /**
    * Returns <i>true/i> if this instance is of the specified class.
    */
  template<class T> bool instanceOf() {
     static T t;
 
     return t.getTag() == getTag();
  }

protected:
  class AkentiResponseImpl {
  public:
    virtual ~AkentiResponseImpl();
    const string& getTag() const;
    void setID(int uid);
    int getID() const;
    void setAkentiMessage(const AkentiMessage& mesg);
    const AkentiMessage& getAkentiMessage() const;
    void toXML(DOMElement* response) const;
    void fromXML(const DOMElement* response);
  protected:
    AkentiResponseImpl(const string& tag);
    virtual void doToXML(DOMElement* response) const {
    } 
    virtual void doFromXML(const DOMElement* response) {
    }
  private:
    string tag;          
    int id;           
    AkentiMessage mesg; 
  };

  AkentiResponse(AkentiResponseImpl* impl);
  ref_ptr<AkentiResponseImpl> impl;

private:

  friend class AkentiResponses;
  void toXML(DOMElement* response) const;
  void fromXML(const DOMElement* response);
  const string& getTag() const;
  typedef AkentiResponseImpl* ImplType;
};

}

#endif

