#ifndef AKENTI_CHECK_POLICY_REQUEST_HPP
#define AKENTI_CHECK_POLICY_REQUEST_HPP

#include "AkentiRequest.hpp"

namespace Akenti {

/**
  * Holds the content of a CheckPolicyRequest.                  <BR>
  *
  * This request is used to collect the <i>PolicyCertificate</i>s
  * and their corresponding <i>UseCondCertificate<i>s.            <BR>
  *
  * @see AkentiRequest
  * @see PolicyCertificate 
  * @see UseCondCertificate 
  */
class CheckPolicyRequest : public AkentiRequest {
 
public:

  /**
    * Default Constructor.
    */
  CheckPolicyRequest();

  /**
    * Sets the name of the resource for which policy is to be collected.
    */
  void setResource(const string& resource);
 
  /**
    * Returns the name the resource.
    */
  const string& getResource() const;

  /**
    * Returns true if we should stop on fatal errors.
    */
  void setStopOnFatalError(bool stopOnError);
 
  /**
    * Sets whether we should stop on a fatal error.
    */
  bool getStopOnFatalError() const;

private:

  friend class AkentiRequest;
  friend class AkentiRequestResponseImplFactory;
  static AkentiRequestImpl* getRequestImpl(); 
  class CheckPolicyRequestImpl;
  typedef CheckPolicyRequestImpl* ImplType; 
};

}

#endif
