#ifndef TREE_NODE_HPP
#define TREE_NODE_HPP

#include <string>
#include "TokenType.hpp"

using std::string;
using namespace Akenti;

namespace Akenti {

/**
  * <i>Tree</i>
  * 
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */
class TreeNode {

public:
  
  /**
    *
    */
  TreeNode(TokenType type, 
           const string& data, 
           TreeNode* leftChild, 
           TreeNode* rightChild) 
    : type(type), data(data), leftChild(leftChild), rightChild(rightChild) {
  }

  /**
    *
    */
  TreeNode(TokenType type, const string& data) 
    : type(type), data(data) , leftChild(NULL), rightChild(NULL) {
  }

  /**
    *
    */
  ~TreeNode() {
    delete(leftChild);
    delete(rightChild);
  }

  /**
    *
    */
  TreeNode* clone() const {
    TreeNode* leftChild = this->leftChild ? this->leftChild->clone() : NULL;
    TreeNode* rightChild = this->rightChild ? this->rightChild->clone() : NULL;
    
    return new TreeNode(type, data, leftChild, rightChild);
  }

  /**
    *
    */
  TokenType getTokenType() const {
    return type;
  }

  /**
    *
    */
  const string& getData() const {
    return data;
  }
  
  TreeNode* getLeftChild() const {
    return leftChild; 
  }

  /**
    *
    */
  TreeNode* getRightChild() const {
    return rightChild; 
  }
  
private:

  TokenType type;

  string data;
  
  TreeNode* leftChild;

  TreeNode* rightChild;

};

} // end of namespace
#endif
