#ifndef AK_URL_CONNECTION_HPP
#define AK_URL_CONNECTION_HPP

#include "ref_ptr.hpp"
#include "URLConnectionImpl.hpp"

/**
  * A <i>URLConnection</i> object is a ref_ptr to a <b>URLConnectionImpl</b>
  * that wraps a <i>URLHandlerImpl</i>. Provides services indirectly 
  * from the URLHandlerImpl.
  *
  * @see URLConnectionImpl
  * @see ref_ptr
  *
  * @version 1.1 00/11/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

namespace Akenti {

class URLConnection : public ref_ptr<URLConnectionImpl> {

public:

  /**
    * Constructs this object 
    *
    * @param impl the URLConnectionImpl object  
    */
  URLConnection(URLConnectionImpl* impl = NULL) 
    : ref_ptr<URLConnectionImpl> (impl) {
  }
  
  /**
    * Decrements the ref_cnt and when the count reaches 0 destroys the 
    * implementation and this object.
    */
  ~URLConnection() {
  }
  
};

} // end of namespace Akenti

#endif
